#
# spec file for package hyprpicker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hyprpicker
Version:        0.4.1
Release:        1.3
Summary:        A wlroots-compatible Wayland color picker
License:        BSD-3-Clause
URL:            https://github.com/hyprwm/hyprpicker
Source:         %{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig(hyprutils) >= 0.2.0
BuildRequires:  pkgconfig(hyprwayland-scanner) >= 0.4.2
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)

%description
A wlroots-compatible Wayland color picker with magnifying lens. It
supports a few different output forms, e.g. RGB, CMYK, HSL, HSV.

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Mon Sep 30 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.4.1:
  Fixes
  * core: avoid crash in done callbacks
* Sun Sep 29 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove changesgenerate from _service
- Update to version 0.4.0:
  New
  * fractional scaling is now supported and on by default. No
    more blur
  * --version, --verbose and --quiet have been added
  Fixes
  * core: minor log cleanups
  * cmake: use CXX_STANDARD instead of a flag
  * events: use enter coords
  Packagers
  * new deps: hyprwayland-scanner>0.4.2, hyprutils>=0.2.0
  MRs
  * fix segmentation fault when cursor_shape_manager_v1 is not
    supported
  * README: add required Debian packages to build
  * cmake: remove unneeded dependencies
  * remove unneeded GLES headers
  * Ensure the manpage location is correct.
  * core: move to hyprwayland-scanner
* Thu Jun  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Switch build to cmake
- Remove deprecated Group tag
- Migrate from deprecated disabled to manual in _service
- Update to version 0.3.0:
  * README: Fixed getconf command in build instructions
  * Makefile: remove
  * CMake: add protocol building and install rule
  * output: colorize BG instead of FG
  * fix: cmyk conversion on pure black
  * core: switch to server-side cursors
  * core: implement more safety around cursor themes
* Sun Apr  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Ensure package neutrality
* Mon Oct 30 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.2.0:
  * core: support conversions from 10-bit formats
  * events: Use xkbcommon for keyboard event handling
  * use crosshair instead of left pointer as cursor
* Wed May 31 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.1.1:
  * core: avoid leaving garbage buffers on exit
  * readme: include new options
* Thu May 18 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0eea883:
  * flake.lock: update nixpkgs
  * CI: update nix install action
* Mon May  1 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 97c5134:
  * readme: include new options
  * clang-format, no-zoom and render-inactive
  * Add support for 24 bit formats
* Tue Mar  7 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version e4c2672:
  * clear LSes at finish
  * disconnect from display on finish
  * don't flush display after disconnect
  * fix autocopy.
  * fix clang build
  * CI: update actions
  * Nix: push to Cachix
  * Add keyboard listener and listen to escape to quit hyprpicker
  * fix issue #17: hyprpicker stops working after a couple of uses
  * Document the --autocopy flag
* Wed Dec  7 2022 Joshua Smith <jsmithfpv@gmail.com>
- Initial commit for git hyprpicker
